# -*- coding: utf-8 -*-
import datetime
import itertools
import json

from odoo.addons.saas_worker.compat import route, http, request
from odoo.addons.saas_worker.util import from_role
from odoo.fields import Datetime

class TrialSecurityController(http.Controller):

    @from_role('om')
    @route('/oe-trial-rules/name', auth='none', type='json')
    def oe_trial_rules_name(self, name):
        trial_rules = request.env['openerp.enterprise.trial.rules'].sudo()
        return {
            'valid': trial_rules._check_dbname(name),
        }

    @from_role("spambot")
    @route("/oe-fetch-latest-trials", auth="public", type="http", save_session=False, readonly=True)
    def fetch_latest_trials(self, max_age=None):
        Trials = request.env["openerp.enterprise.trial.log"].sudo()

        max_age = int(max_age or 2)

        # some arbitrary filter for "suspicious" trials that should be scanned,
        # recent enough but not too recent. Filter on actually installed `website`
        # app, rather than initially selected at trial, since it can be installed afterwards
        # TODO: should be made configurable
        domain = [
            ("database_id.app_ids.name", "=", "website"),
            ("database_id.url", "!=", ""),
            ("create_date", "<", datetime.datetime.now() - datetime.timedelta(minutes=20)),
            ("create_date", ">", datetime.datetime.now() - datetime.timedelta(days=max_age)),
        ]
        trials = Trials.search(domain)

        # keep unique URLs only, some sites are registered multiple times after being dropped
        results = [
            {'url': url, 'create_date': Datetime.to_string(max(t.create_date for t in trials))}
            for url, trials in itertools.groupby(trials, key=lambda t: t.database_id.url)
        ]
        return json.dumps(results)
